@@ -3,4 +3,4 @@ from .grand_composite_curve import GrandCompositeCurve  # noqa
 from .line import extract_x, y_range  # noqa
 from .pinch_analyzer import PinchAnalyzer  # noqa
 from .stream import Stream  # noqa
-from .tq_diagram import TQDiagram  # noqa
+from .tq_diagram import TQDiagram, get_possible_minimum_temp_diff_range  # noqa
